pub fn set_console_hook(hook: ConsoleHook)Expand description
Install a hook that receives each formatted log line (and other console
output routed via console_println) instead of stderr.
pub fn set_console_hook(hook: ConsoleHook)Install a hook that receives each formatted log line (and other console
output routed via console_println) instead of stderr.